<template>
  <div class="app-container">
    <div style="display: flex;justify-content: space-between">
      <el-form :inline="true" style="display: flex;align-items: center;flex-wrap: wrap;" >
        <el-form-item>
          <el-button
              type="primary"
              plain
              @click="openDialog('add',{})"
          >开始组卷考试</el-button>
        </el-form-item>
        <el-form-item label="考试名称：" >
          <el-input v-model="data.queryParams.name" placeholder="请输入考试名称"></el-input>
        </el-form-item>
        <el-form-item label="科目/类别：" >
          <el-cascader
              style="width: 100%"
              ref="classifyRef"
              v-model="data.queryParams.categoryId"
              :options="data.classifyList"
              :props="data.props"
              clearable
              :show-all-levels="false"
              @change="handleChange"
          />
        </el-form-item>
        <el-form-item >
          <el-button
              type="primary"
              @click="getList"
          >查询</el-button>
          <el-button
              type="primary"
              plain
              @click="reset"
          >重置</el-button>
        </el-form-item>
      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading" :data="dataList" :border="true">
      <el-table-column label="编号" prop="code" align="center" width="135" />
      <el-table-column label="考试名称" prop="name" align="center"  />
      <el-table-column label="企业名称" prop="companyName" align="center"  />
      <el-table-column label="创建账户" prop="createBy" align="center"  />
      <el-table-column label="科目/类别" prop="categoryName" align="center"  />
      <el-table-column label="完成人数/总人数" prop="" align="center"  width="135">
        <template #default="scope">
          <span>{{scope.row.paperStudentInfoVO.finishCount}}/{{scope.row.paperStudentInfoVO.studentCount}}</span>
        </template>
      </el-table-column>
      <el-table-column label="合格人数" prop="" align="center">
        <template #default="scope">
          <span>{{scope.row.paperStudentInfoVO.passStudentCount}}</span>
        </template>
      </el-table-column>
      <el-table-column label="平均分数" prop="" align="center" >
        <template #default="scope">
          <span>{{scope.row.paperStudentInfoVO.avgScore}}</span>
        </template>
      </el-table-column>
      <el-table-column label="合格分/总分" prop="" align="center" width="120" >
        <template #default="scope">
          <span>{{scope.row.passScore}}/{{scope.row.judgeNum * scope.row.judgeScore + scope.row.multiNum * scope.row.multiScore + scope.row.singleNum * scope.row.singleScore+ scope.row.easyNum * scope.row.easyScore}}</span>
        </template>
      </el-table-column>
      <el-table-column label="合格率" prop="passRate" align="center" />
      <el-table-column label="限制时长/分钟" prop="limitTime" align="center"  width="120" >
        <template #default="scope">
          <span v-if="scope.row.limitTime == 0">不限时</span>
          <span v-else>{{scope.row.limitTime}}</span>
        </template>
      </el-table-column>
      <el-table-column label="考试截止时间" prop="deadlineNum" align="center"  width="120" >
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width"  width="260">
        <template #default="scope">
          <el-button link type="primary" @click="viewQuestion(scope.row)">预览</el-button>
          <el-button link type="primary" @click="toStuChoose(scope.row)">人员数据</el-button>
          <el-button link type="primary" @click="openDialog('edit',scope.row)">编辑</el-button>
          <el-button link type="danger" @click="handleDelete(scope.row)">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
        v-show="total > 0"
        :total="total"
        v-model:page="queryParams.pageNum"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
    <exam-dialog ref="dialogRef" @getList=getList></exam-dialog>

    <exam-question ref="questionRef" @getList=getList></exam-question>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import examDialog from './components/examDialog.vue'
import examQuestion from './components/viewExamQuestion.vue'
import Cookies from "js-cookie";
import {useRoute, useRouter} from 'vue-router'
const router = useRouter()
import {delQuestionBank, getQuestionBank} from "@/api/onlineEducation/questionBank";
import {delBatch, getBatch} from "@/api/onlineEducation/batch";
import {delExam, getExam} from "@/api/onlineEducation/exam";
import {getClassification} from "@/api/onlineEducation/courseClass";
const route = useRoute()

const { proxy } = getCurrentInstance();
const loading = ref(false);
const dialogRef = ref();
const questionRef = ref();
const classifyRef = ref(null)
const data = reactive({
  queryParams: {
    name:'',
    categoryId: null,
    pageNum: 1,
    pageSize: 10,
  },
  total: 0,
  dataList: [],
  isAdmin: false,
  companyName: '',
  remainPeriod: null,
  categoryList: [],
  props: {
    checkStrictly: true,
  },

});

const { queryParams, total, dataList } = toRefs(data);

onMounted(async ()=>{
  if(route.query.val){
    const val = JSON.parse(route.query.val)
    if(val){
      data.queryParams.pageNum = val.pageNum;
      data.queryParams.pageSize = val.pageSize;
    }
  }
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  if(userInfo.userType === 0){
    data.isAdmin = true;
  }else {
    data.isAdmin = false;
    data.companyName = userInfo.companyName
  }
  await getClassifyList();
  await getList()
})
onUnmounted(()=>{

})

const getList = async () => {
  loading.value = true
  const res = await getExam(data.queryParams)
  if(res.code == 200){
    data.dataList = res.data.list.map(item => {
      return {
        ...item,
        passRate: item.paperStudentInfoVO.passStudentCount ===0 && item.paperStudentInfoVO.studentCount ===0  ? '0%': (item.paperStudentInfoVO.passStudentCount / item.paperStudentInfoVO.studentCount).toFixed(2) *100 + '%',
        deadlineNum: item.deadline ? item.deadline.slice(0,10) : ''
      }
    })

    data.total = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
}

const openDialog = (type, value) => {
  dialogRef.value.openDialog(type, value);
}

/** 重置新增的表单以及其他数据  */
function reset() {
  data.queryParams = {
    name:'',
    categoryId: null,
    pageNum: 1,
    pageSize: 10,
  }
  getList()
}
const handleDelete = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await delExam(val.id)
        if(res.code == 200){
          ElMessage.success('数据删除成功')
          await getList()
        }else{
          ElMessage.warning(res.message)
        }
      })
}
const toStuChoose = (val) => {
  const obj = {
    pageNum: data.queryParams.pageNum,
    pageSize: data.queryParams.pageSize,
    id: val.id,
    type: 'index'
  }
  // val.pageNum = data.queryParams.pageNum;
  // val.pageSize = data.queryParams.pageSize
  const v = JSON.stringify(obj)
  router.push({ path: "/examStu", query: { val: v } });
}
const viewQuestion = (val) => {
  questionRef.value.openDialog(val)
}
const handleChange = ()=> {
  console.log("label====",classifyRef.value.getCheckedNodes()[0].value)
  data.queryParams.categoryId = classifyRef.value.getCheckedNodes()[0].value
  // 我这里只是打印了一下label的值哦，需要赋值的话自己去赋值哦
  if (classifyRef.value.popperVisible) {
    classifyRef.value.togglePopperVisible()
  }
}
const  getClassifyList = async () => {
  const res = await getClassification();
  if(res.code === 200){
    data.classifyList = recursion(res.data)
  }else{
    ElMessage.warning(res.message)
  }
}
const recursion = (data) => {
  let tmp = []
  for (let i = 0; i < data.length; i++) {
    let item = data[i]
    // children为空
    if (item.children&& item.children.length==0) {
      tmp.push({
        value: item.id,
        label: item.name
      })
      // 有children
    } else {
      tmp.push({
        value: item.id,
        label: item.name,
        children:recursion(item.children)
      })
    }
  }
  return tmp;
}
</script>
